# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryResultMetadataSummary(object):
    """
    Summary containing the metadata about the query result set.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new QueryResultMetadataSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param query_result_row_type_summaries:
            The value to assign to the query_result_row_type_summaries property of this QueryResultMetadataSummary.
        :type query_result_row_type_summaries: list[oci.apm_traces.models.QueryResultRowTypeSummary]

        :param source_name:
            The value to assign to the source_name property of this QueryResultMetadataSummary.
        :type source_name: str

        :param query_results_grouped_by:
            The value to assign to the query_results_grouped_by property of this QueryResultMetadataSummary.
        :type query_results_grouped_by: list[oci.apm_traces.models.QueryResultsGroupedBySummary]

        :param query_results_ordered_by:
            The value to assign to the query_results_ordered_by property of this QueryResultMetadataSummary.
        :type query_results_ordered_by: list[oci.apm_traces.models.QueryResultsOrderedBySummary]

        :param time_series_interval_in_mins:
            The value to assign to the time_series_interval_in_mins property of this QueryResultMetadataSummary.
        :type time_series_interval_in_mins: int

        """
        self.swagger_types = {
            'query_result_row_type_summaries': 'list[QueryResultRowTypeSummary]',
            'source_name': 'str',
            'query_results_grouped_by': 'list[QueryResultsGroupedBySummary]',
            'query_results_ordered_by': 'list[QueryResultsOrderedBySummary]',
            'time_series_interval_in_mins': 'int'
        }

        self.attribute_map = {
            'query_result_row_type_summaries': 'queryResultRowTypeSummaries',
            'source_name': 'sourceName',
            'query_results_grouped_by': 'queryResultsGroupedBy',
            'query_results_ordered_by': 'queryResultsOrderedBy',
            'time_series_interval_in_mins': 'timeSeriesIntervalInMins'
        }

        self._query_result_row_type_summaries = None
        self._source_name = None
        self._query_results_grouped_by = None
        self._query_results_ordered_by = None
        self._time_series_interval_in_mins = None

    @property
    def query_result_row_type_summaries(self):
        """
        Gets the query_result_row_type_summaries of this QueryResultMetadataSummary.
        A collection of QueryResultRowTypeSummary objects that describe the type and properties of the individual row elements of the query rows
        being returned.  The ith element in this list contains the QueryResultRowTypeSummary of the ith key value pair in the QueryResultRowData map.


        :return: The query_result_row_type_summaries of this QueryResultMetadataSummary.
        :rtype: list[oci.apm_traces.models.QueryResultRowTypeSummary]
        """
        return self._query_result_row_type_summaries

    @query_result_row_type_summaries.setter
    def query_result_row_type_summaries(self, query_result_row_type_summaries):
        """
        Sets the query_result_row_type_summaries of this QueryResultMetadataSummary.
        A collection of QueryResultRowTypeSummary objects that describe the type and properties of the individual row elements of the query rows
        being returned.  The ith element in this list contains the QueryResultRowTypeSummary of the ith key value pair in the QueryResultRowData map.


        :param query_result_row_type_summaries: The query_result_row_type_summaries of this QueryResultMetadataSummary.
        :type: list[oci.apm_traces.models.QueryResultRowTypeSummary]
        """
        self._query_result_row_type_summaries = query_result_row_type_summaries

    @property
    def source_name(self):
        """
        Gets the source_name of this QueryResultMetadataSummary.
        Source of the query result set (traces, spans, etc).


        :return: The source_name of this QueryResultMetadataSummary.
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """
        Sets the source_name of this QueryResultMetadataSummary.
        Source of the query result set (traces, spans, etc).


        :param source_name: The source_name of this QueryResultMetadataSummary.
        :type: str
        """
        self._source_name = source_name

    @property
    def query_results_grouped_by(self):
        """
        Gets the query_results_grouped_by of this QueryResultMetadataSummary.
        Columns or attributes of the query rows  which are group by values.  This is a list of ResultsGroupedBy summary objects,
        and the list will contain as many elements as the attributes and aggregate functions in the group by clause in the select query.


        :return: The query_results_grouped_by of this QueryResultMetadataSummary.
        :rtype: list[oci.apm_traces.models.QueryResultsGroupedBySummary]
        """
        return self._query_results_grouped_by

    @query_results_grouped_by.setter
    def query_results_grouped_by(self, query_results_grouped_by):
        """
        Sets the query_results_grouped_by of this QueryResultMetadataSummary.
        Columns or attributes of the query rows  which are group by values.  This is a list of ResultsGroupedBy summary objects,
        and the list will contain as many elements as the attributes and aggregate functions in the group by clause in the select query.


        :param query_results_grouped_by: The query_results_grouped_by of this QueryResultMetadataSummary.
        :type: list[oci.apm_traces.models.QueryResultsGroupedBySummary]
        """
        self._query_results_grouped_by = query_results_grouped_by

    @property
    def query_results_ordered_by(self):
        """
        Gets the query_results_ordered_by of this QueryResultMetadataSummary.
        Order by which the query results are organized.  This is a list of queryResultsOrderedBy summary objects, and the list
        will contain more than one OrderedBy summary object, if the sort was multidimensional.


        :return: The query_results_ordered_by of this QueryResultMetadataSummary.
        :rtype: list[oci.apm_traces.models.QueryResultsOrderedBySummary]
        """
        return self._query_results_ordered_by

    @query_results_ordered_by.setter
    def query_results_ordered_by(self, query_results_ordered_by):
        """
        Sets the query_results_ordered_by of this QueryResultMetadataSummary.
        Order by which the query results are organized.  This is a list of queryResultsOrderedBy summary objects, and the list
        will contain more than one OrderedBy summary object, if the sort was multidimensional.


        :param query_results_ordered_by: The query_results_ordered_by of this QueryResultMetadataSummary.
        :type: list[oci.apm_traces.models.QueryResultsOrderedBySummary]
        """
        self._query_results_ordered_by = query_results_ordered_by

    @property
    def time_series_interval_in_mins(self):
        """
        Gets the time_series_interval_in_mins of this QueryResultMetadataSummary.
        Interval for the time series function in minutes.


        :return: The time_series_interval_in_mins of this QueryResultMetadataSummary.
        :rtype: int
        """
        return self._time_series_interval_in_mins

    @time_series_interval_in_mins.setter
    def time_series_interval_in_mins(self, time_series_interval_in_mins):
        """
        Sets the time_series_interval_in_mins of this QueryResultMetadataSummary.
        Interval for the time series function in minutes.


        :param time_series_interval_in_mins: The time_series_interval_in_mins of this QueryResultMetadataSummary.
        :type: int
        """
        self._time_series_interval_in_mins = time_series_interval_in_mins

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BulkEditResource(object):
    """
    BulkEditResource model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BulkEditResource object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this BulkEditResource.
        :type id: str

        :param resource_type:
            The value to assign to the resource_type property of this BulkEditResource.
        :type resource_type: str

        :param metadata:
            The value to assign to the metadata property of this BulkEditResource.
        :type metadata: dict(str, str)

        """
        self.swagger_types = {
            'id': 'str',
            'resource_type': 'str',
            'metadata': 'dict(str, str)'
        }

        self.attribute_map = {
            'id': 'id',
            'resource_type': 'resourceType',
            'metadata': 'metadata'
        }

        self._id = None
        self._resource_type = None
        self._metadata = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this BulkEditResource.
        The unique OCID of the resource.


        :return: The id of this BulkEditResource.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BulkEditResource.
        The unique OCID of the resource.


        :param id: The id of this BulkEditResource.
        :type: str
        """
        self._id = id

    @property
    def resource_type(self):
        """
        **[Required]** Gets the resource_type of this BulkEditResource.
        The type of resource. See :func:`bulk_edit_resource_types`.


        :return: The resource_type of this BulkEditResource.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """
        Sets the resource_type of this BulkEditResource.
        The type of resource. See :func:`bulk_edit_resource_types`.


        :param resource_type: The resource_type of this BulkEditResource.
        :type: str
        """
        self._resource_type = resource_type

    @property
    def metadata(self):
        """
        Gets the metadata of this BulkEditResource.
        Additional information that identifies the resource for bulk editing of tags. This information is provided in the resource's API documentation.


        :return: The metadata of this BulkEditResource.
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this BulkEditResource.
        Additional information that identifies the resource for bulk editing of tags. This information is provided in the resource's API documentation.


        :param metadata: The metadata of this BulkEditResource.
        :type: dict(str, str)
        """
        self._metadata = metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CustomProperty(object):
    """
    Custom Property Definition
    """

    #: A constant which can be used with the data_type property of a CustomProperty.
    #: This constant has a value of "TEXT"
    DATA_TYPE_TEXT = "TEXT"

    #: A constant which can be used with the data_type property of a CustomProperty.
    #: This constant has a value of "RICH_TEXT"
    DATA_TYPE_RICH_TEXT = "RICH_TEXT"

    #: A constant which can be used with the data_type property of a CustomProperty.
    #: This constant has a value of "BOOLEAN"
    DATA_TYPE_BOOLEAN = "BOOLEAN"

    #: A constant which can be used with the data_type property of a CustomProperty.
    #: This constant has a value of "NUMBER"
    DATA_TYPE_NUMBER = "NUMBER"

    #: A constant which can be used with the data_type property of a CustomProperty.
    #: This constant has a value of "DATE"
    DATA_TYPE_DATE = "DATE"

    #: A constant which can be used with the lifecycle_state property of a CustomProperty.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a CustomProperty.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a CustomProperty.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a CustomProperty.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a CustomProperty.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a CustomProperty.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a CustomProperty.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a CustomProperty.
    #: This constant has a value of "MOVING"
    LIFECYCLE_STATE_MOVING = "MOVING"

    def __init__(self, **kwargs):
        """
        Initializes a new CustomProperty object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this CustomProperty.
        :type key: str

        :param display_name:
            The value to assign to the display_name property of this CustomProperty.
        :type display_name: str

        :param data_type:
            The value to assign to the data_type property of this CustomProperty.
            Allowed values for this property are: "TEXT", "RICH_TEXT", "BOOLEAN", "NUMBER", "DATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type data_type: str

        :param description:
            The value to assign to the description property of this CustomProperty.
        :type description: str

        :param namespace_name:
            The value to assign to the namespace_name property of this CustomProperty.
        :type namespace_name: str

        :param is_list_type:
            The value to assign to the is_list_type property of this CustomProperty.
        :type is_list_type: bool

        :param is_sortable:
            The value to assign to the is_sortable property of this CustomProperty.
        :type is_sortable: bool

        :param is_filterable:
            The value to assign to the is_filterable property of this CustomProperty.
        :type is_filterable: bool

        :param is_multi_valued:
            The value to assign to the is_multi_valued property of this CustomProperty.
        :type is_multi_valued: bool

        :param is_hidden:
            The value to assign to the is_hidden property of this CustomProperty.
        :type is_hidden: bool

        :param is_editable:
            The value to assign to the is_editable property of this CustomProperty.
        :type is_editable: bool

        :param is_shown_in_list:
            The value to assign to the is_shown_in_list property of this CustomProperty.
        :type is_shown_in_list: bool

        :param is_service_defined:
            The value to assign to the is_service_defined property of this CustomProperty.
        :type is_service_defined: bool

        :param is_hidden_in_search:
            The value to assign to the is_hidden_in_search property of this CustomProperty.
        :type is_hidden_in_search: bool

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this CustomProperty.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this CustomProperty.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this CustomProperty.
        :type time_updated: datetime

        :param created_by_id:
            The value to assign to the created_by_id property of this CustomProperty.
        :type created_by_id: str

        :param updated_by_id:
            The value to assign to the updated_by_id property of this CustomProperty.
        :type updated_by_id: str

        :param usage_count:
            The value to assign to the usage_count property of this CustomProperty.
        :type usage_count: int

        :param is_event_enabled:
            The value to assign to the is_event_enabled property of this CustomProperty.
        :type is_event_enabled: bool

        :param scope:
            The value to assign to the scope property of this CustomProperty.
        :type scope: list[oci.data_catalog.models.CustomPropertyTypeUsage]

        :param allowed_values:
            The value to assign to the allowed_values property of this CustomProperty.
        :type allowed_values: list[str]

        :param events:
            The value to assign to the events property of this CustomProperty.
        :type events: list[oci.data_catalog.models.EventConfig]

        :param properties:
            The value to assign to the properties property of this CustomProperty.
        :type properties: dict(str, dict(str, str))

        """
        self.swagger_types = {
            'key': 'str',
            'display_name': 'str',
            'data_type': 'str',
            'description': 'str',
            'namespace_name': 'str',
            'is_list_type': 'bool',
            'is_sortable': 'bool',
            'is_filterable': 'bool',
            'is_multi_valued': 'bool',
            'is_hidden': 'bool',
            'is_editable': 'bool',
            'is_shown_in_list': 'bool',
            'is_service_defined': 'bool',
            'is_hidden_in_search': 'bool',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'created_by_id': 'str',
            'updated_by_id': 'str',
            'usage_count': 'int',
            'is_event_enabled': 'bool',
            'scope': 'list[CustomPropertyTypeUsage]',
            'allowed_values': 'list[str]',
            'events': 'list[EventConfig]',
            'properties': 'dict(str, dict(str, str))'
        }

        self.attribute_map = {
            'key': 'key',
            'display_name': 'displayName',
            'data_type': 'dataType',
            'description': 'description',
            'namespace_name': 'namespaceName',
            'is_list_type': 'isListType',
            'is_sortable': 'isSortable',
            'is_filterable': 'isFilterable',
            'is_multi_valued': 'isMultiValued',
            'is_hidden': 'isHidden',
            'is_editable': 'isEditable',
            'is_shown_in_list': 'isShownInList',
            'is_service_defined': 'isServiceDefined',
            'is_hidden_in_search': 'isHiddenInSearch',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'created_by_id': 'createdById',
            'updated_by_id': 'updatedById',
            'usage_count': 'usageCount',
            'is_event_enabled': 'isEventEnabled',
            'scope': 'scope',
            'allowed_values': 'allowedValues',
            'events': 'events',
            'properties': 'properties'
        }

        self._key = None
        self._display_name = None
        self._data_type = None
        self._description = None
        self._namespace_name = None
        self._is_list_type = None
        self._is_sortable = None
        self._is_filterable = None
        self._is_multi_valued = None
        self._is_hidden = None
        self._is_editable = None
        self._is_shown_in_list = None
        self._is_service_defined = None
        self._is_hidden_in_search = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._created_by_id = None
        self._updated_by_id = None
        self._usage_count = None
        self._is_event_enabled = None
        self._scope = None
        self._allowed_values = None
        self._events = None
        self._properties = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this CustomProperty.
        Unique data asset key that is immutable.


        :return: The key of this CustomProperty.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this CustomProperty.
        Unique data asset key that is immutable.


        :param key: The key of this CustomProperty.
        :type: str
        """
        self._key = key

    @property
    def display_name(self):
        """
        Gets the display_name of this CustomProperty.
        Display name of the custom property


        :return: The display_name of this CustomProperty.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CustomProperty.
        Display name of the custom property


        :param display_name: The display_name of this CustomProperty.
        :type: str
        """
        self._display_name = display_name

    @property
    def data_type(self):
        """
        Gets the data_type of this CustomProperty.
        Data type of the custom property

        Allowed values for this property are: "TEXT", "RICH_TEXT", "BOOLEAN", "NUMBER", "DATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The data_type of this CustomProperty.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """
        Sets the data_type of this CustomProperty.
        Data type of the custom property


        :param data_type: The data_type of this CustomProperty.
        :type: str
        """
        allowed_values = ["TEXT", "RICH_TEXT", "BOOLEAN", "NUMBER", "DATE"]
        if not value_allowed_none_or_none_sentinel(data_type, allowed_values):
            data_type = 'UNKNOWN_ENUM_VALUE'
        self._data_type = data_type

    @property
    def description(self):
        """
        Gets the description of this CustomProperty.
        Description for the custom property


        :return: The description of this CustomProperty.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CustomProperty.
        Description for the custom property


        :param description: The description of this CustomProperty.
        :type: str
        """
        self._description = description

    @property
    def namespace_name(self):
        """
        Gets the namespace_name of this CustomProperty.
        Namespace name of the custom property


        :return: The namespace_name of this CustomProperty.
        :rtype: str
        """
        return self._namespace_name

    @namespace_name.setter
    def namespace_name(self, namespace_name):
        """
        Sets the namespace_name of this CustomProperty.
        Namespace name of the custom property


        :param namespace_name: The namespace_name of this CustomProperty.
        :type: str
        """
        self._namespace_name = namespace_name

    @property
    def is_list_type(self):
        """
        Gets the is_list_type of this CustomProperty.
        Is this property allowed to have list of values


        :return: The is_list_type of this CustomProperty.
        :rtype: bool
        """
        return self._is_list_type

    @is_list_type.setter
    def is_list_type(self, is_list_type):
        """
        Sets the is_list_type of this CustomProperty.
        Is this property allowed to have list of values


        :param is_list_type: The is_list_type of this CustomProperty.
        :type: bool
        """
        self._is_list_type = is_list_type

    @property
    def is_sortable(self):
        """
        Gets the is_sortable of this CustomProperty.
        If this field allows to sort from UI


        :return: The is_sortable of this CustomProperty.
        :rtype: bool
        """
        return self._is_sortable

    @is_sortable.setter
    def is_sortable(self, is_sortable):
        """
        Sets the is_sortable of this CustomProperty.
        If this field allows to sort from UI


        :param is_sortable: The is_sortable of this CustomProperty.
        :type: bool
        """
        self._is_sortable = is_sortable

    @property
    def is_filterable(self):
        """
        Gets the is_filterable of this CustomProperty.
        If this field allows to filter or create facets from UI


        :return: The is_filterable of this CustomProperty.
        :rtype: bool
        """
        return self._is_filterable

    @is_filterable.setter
    def is_filterable(self, is_filterable):
        """
        Sets the is_filterable of this CustomProperty.
        If this field allows to filter or create facets from UI


        :param is_filterable: The is_filterable of this CustomProperty.
        :type: bool
        """
        self._is_filterable = is_filterable

    @property
    def is_multi_valued(self):
        """
        Gets the is_multi_valued of this CustomProperty.
        If this field allows multiple values to be set


        :return: The is_multi_valued of this CustomProperty.
        :rtype: bool
        """
        return self._is_multi_valued

    @is_multi_valued.setter
    def is_multi_valued(self, is_multi_valued):
        """
        Sets the is_multi_valued of this CustomProperty.
        If this field allows multiple values to be set


        :param is_multi_valued: The is_multi_valued of this CustomProperty.
        :type: bool
        """
        self._is_multi_valued = is_multi_valued

    @property
    def is_hidden(self):
        """
        Gets the is_hidden of this CustomProperty.
        If this field is a hidden field


        :return: The is_hidden of this CustomProperty.
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """
        Sets the is_hidden of this CustomProperty.
        If this field is a hidden field


        :param is_hidden: The is_hidden of this CustomProperty.
        :type: bool
        """
        self._is_hidden = is_hidden

    @property
    def is_editable(self):
        """
        Gets the is_editable of this CustomProperty.
        If this field is a editable field


        :return: The is_editable of this CustomProperty.
        :rtype: bool
        """
        return self._is_editable

    @is_editable.setter
    def is_editable(self, is_editable):
        """
        Sets the is_editable of this CustomProperty.
        If this field is a editable field


        :param is_editable: The is_editable of this CustomProperty.
        :type: bool
        """
        self._is_editable = is_editable

    @property
    def is_shown_in_list(self):
        """
        Gets the is_shown_in_list of this CustomProperty.
        If this field is displayed in a list view of applicable objects.


        :return: The is_shown_in_list of this CustomProperty.
        :rtype: bool
        """
        return self._is_shown_in_list

    @is_shown_in_list.setter
    def is_shown_in_list(self, is_shown_in_list):
        """
        Sets the is_shown_in_list of this CustomProperty.
        If this field is displayed in a list view of applicable objects.


        :param is_shown_in_list: The is_shown_in_list of this CustomProperty.
        :type: bool
        """
        self._is_shown_in_list = is_shown_in_list

    @property
    def is_service_defined(self):
        """
        Gets the is_service_defined of this CustomProperty.
        If this field is defined by service or by a user


        :return: The is_service_defined of this CustomProperty.
        :rtype: bool
        """
        return self._is_service_defined

    @is_service_defined.setter
    def is_service_defined(self, is_service_defined):
        """
        Sets the is_service_defined of this CustomProperty.
        If this field is defined by service or by a user


        :param is_service_defined: The is_service_defined of this CustomProperty.
        :type: bool
        """
        self._is_service_defined = is_service_defined

    @property
    def is_hidden_in_search(self):
        """
        Gets the is_hidden_in_search of this CustomProperty.
        If this field is allowed to pop in search results


        :return: The is_hidden_in_search of this CustomProperty.
        :rtype: bool
        """
        return self._is_hidden_in_search

    @is_hidden_in_search.setter
    def is_hidden_in_search(self, is_hidden_in_search):
        """
        Sets the is_hidden_in_search of this CustomProperty.
        If this field is allowed to pop in search results


        :param is_hidden_in_search: The is_hidden_in_search of this CustomProperty.
        :type: bool
        """
        self._is_hidden_in_search = is_hidden_in_search

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this CustomProperty.
        The current state of the custom property.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this CustomProperty.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this CustomProperty.
        The current state of the custom property.


        :param lifecycle_state: The lifecycle_state of this CustomProperty.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        Gets the time_created of this CustomProperty.
        The date and time the custom property was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this CustomProperty.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this CustomProperty.
        The date and time the custom property was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this CustomProperty.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this CustomProperty.
        The last time that any change was made to the custom property. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this CustomProperty.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this CustomProperty.
        The last time that any change was made to the custom property. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this CustomProperty.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def created_by_id(self):
        """
        Gets the created_by_id of this CustomProperty.
        OCID of the user who created the custom property.


        :return: The created_by_id of this CustomProperty.
        :rtype: str
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """
        Sets the created_by_id of this CustomProperty.
        OCID of the user who created the custom property.


        :param created_by_id: The created_by_id of this CustomProperty.
        :type: str
        """
        self._created_by_id = created_by_id

    @property
    def updated_by_id(self):
        """
        Gets the updated_by_id of this CustomProperty.
        OCID of the user who last modified the custom property.


        :return: The updated_by_id of this CustomProperty.
        :rtype: str
        """
        return self._updated_by_id

    @updated_by_id.setter
    def updated_by_id(self, updated_by_id):
        """
        Sets the updated_by_id of this CustomProperty.
        OCID of the user who last modified the custom property.


        :param updated_by_id: The updated_by_id of this CustomProperty.
        :type: str
        """
        self._updated_by_id = updated_by_id

    @property
    def usage_count(self):
        """
        Gets the usage_count of this CustomProperty.
        Total number of first class objects using this custom property


        :return: The usage_count of this CustomProperty.
        :rtype: int
        """
        return self._usage_count

    @usage_count.setter
    def usage_count(self, usage_count):
        """
        Sets the usage_count of this CustomProperty.
        Total number of first class objects using this custom property


        :param usage_count: The usage_count of this CustomProperty.
        :type: int
        """
        self._usage_count = usage_count

    @property
    def is_event_enabled(self):
        """
        Gets the is_event_enabled of this CustomProperty.
        If an OCI Event will be emitted when the custom property is modified.


        :return: The is_event_enabled of this CustomProperty.
        :rtype: bool
        """
        return self._is_event_enabled

    @is_event_enabled.setter
    def is_event_enabled(self, is_event_enabled):
        """
        Sets the is_event_enabled of this CustomProperty.
        If an OCI Event will be emitted when the custom property is modified.


        :param is_event_enabled: The is_event_enabled of this CustomProperty.
        :type: bool
        """
        self._is_event_enabled = is_event_enabled

    @property
    def scope(self):
        """
        Gets the scope of this CustomProperty.
        The set of object types to which the custom property applies.


        :return: The scope of this CustomProperty.
        :rtype: list[oci.data_catalog.models.CustomPropertyTypeUsage]
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this CustomProperty.
        The set of object types to which the custom property applies.


        :param scope: The scope of this CustomProperty.
        :type: list[oci.data_catalog.models.CustomPropertyTypeUsage]
        """
        self._scope = scope

    @property
    def allowed_values(self):
        """
        Gets the allowed_values of this CustomProperty.
        Allowed values for the custom property if any


        :return: The allowed_values of this CustomProperty.
        :rtype: list[str]
        """
        return self._allowed_values

    @allowed_values.setter
    def allowed_values(self, allowed_values):
        """
        Sets the allowed_values of this CustomProperty.
        Allowed values for the custom property if any


        :param allowed_values: The allowed_values of this CustomProperty.
        :type: list[str]
        """
        self._allowed_values = allowed_values

    @property
    def events(self):
        """
        Gets the events of this CustomProperty.
        Event configuration for this custom property, against the desired subset of object types to which the property applies.


        :return: The events of this CustomProperty.
        :rtype: list[oci.data_catalog.models.EventConfig]
        """
        return self._events

    @events.setter
    def events(self, events):
        """
        Sets the events of this CustomProperty.
        Event configuration for this custom property, against the desired subset of object types to which the property applies.


        :param events: The events of this CustomProperty.
        :type: list[oci.data_catalog.models.EventConfig]
        """
        self._events = events

    @property
    def properties(self):
        """
        Gets the properties of this CustomProperty.
        A map of maps that contains the properties which are specific to the asset type. Each data asset type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        data assets have required properties within the \"default\" category.
        Example: `{\"properties\": { \"default\": { \"host\": \"host1\", \"port\": \"1521\", \"database\": \"orcl\"}}}`


        :return: The properties of this CustomProperty.
        :rtype: dict(str, dict(str, str))
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this CustomProperty.
        A map of maps that contains the properties which are specific to the asset type. Each data asset type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        data assets have required properties within the \"default\" category.
        Example: `{\"properties\": { \"default\": { \"host\": \"host1\", \"port\": \"1521\", \"database\": \"orcl\"}}}`


        :param properties: The properties of this CustomProperty.
        :type: dict(str, dict(str, str))
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SummaryStatistics(object):
    """
    Contains common summary statistics.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SummaryStatistics object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param minimum:
            The value to assign to the minimum property of this SummaryStatistics.
        :type minimum: float

        :param maximum:
            The value to assign to the maximum property of this SummaryStatistics.
        :type maximum: float

        :param average:
            The value to assign to the average property of this SummaryStatistics.
        :type average: float

        :param median:
            The value to assign to the median property of this SummaryStatistics.
        :type median: float

        :param lower_quartile:
            The value to assign to the lower_quartile property of this SummaryStatistics.
        :type lower_quartile: float

        :param upper_quartile:
            The value to assign to the upper_quartile property of this SummaryStatistics.
        :type upper_quartile: float

        """
        self.swagger_types = {
            'minimum': 'float',
            'maximum': 'float',
            'average': 'float',
            'median': 'float',
            'lower_quartile': 'float',
            'upper_quartile': 'float'
        }

        self.attribute_map = {
            'minimum': 'minimum',
            'maximum': 'maximum',
            'average': 'average',
            'median': 'median',
            'lower_quartile': 'lowerQuartile',
            'upper_quartile': 'upperQuartile'
        }

        self._minimum = None
        self._maximum = None
        self._average = None
        self._median = None
        self._lower_quartile = None
        self._upper_quartile = None

    @property
    def minimum(self):
        """
        **[Required]** Gets the minimum of this SummaryStatistics.
        The smallest number in the data set.


        :return: The minimum of this SummaryStatistics.
        :rtype: float
        """
        return self._minimum

    @minimum.setter
    def minimum(self, minimum):
        """
        Sets the minimum of this SummaryStatistics.
        The smallest number in the data set.


        :param minimum: The minimum of this SummaryStatistics.
        :type: float
        """
        self._minimum = minimum

    @property
    def maximum(self):
        """
        **[Required]** Gets the maximum of this SummaryStatistics.
        The largest number in the data set.


        :return: The maximum of this SummaryStatistics.
        :rtype: float
        """
        return self._maximum

    @maximum.setter
    def maximum(self, maximum):
        """
        Sets the maximum of this SummaryStatistics.
        The largest number in the data set.


        :param maximum: The maximum of this SummaryStatistics.
        :type: float
        """
        self._maximum = maximum

    @property
    def average(self):
        """
        **[Required]** Gets the average of this SummaryStatistics.
        The average number in the data set.


        :return: The average of this SummaryStatistics.
        :rtype: float
        """
        return self._average

    @average.setter
    def average(self, average):
        """
        Sets the average of this SummaryStatistics.
        The average number in the data set.


        :param average: The average of this SummaryStatistics.
        :type: float
        """
        self._average = average

    @property
    def median(self):
        """
        **[Required]** Gets the median of this SummaryStatistics.
        The middle number in the data set.


        :return: The median of this SummaryStatistics.
        :rtype: float
        """
        return self._median

    @median.setter
    def median(self, median):
        """
        Sets the median of this SummaryStatistics.
        The middle number in the data set.


        :param median: The median of this SummaryStatistics.
        :type: float
        """
        self._median = median

    @property
    def lower_quartile(self):
        """
        **[Required]** Gets the lower_quartile of this SummaryStatistics.
        The middle number between the smallest number and the median of the data set. It's also known as the 25th quartile.


        :return: The lower_quartile of this SummaryStatistics.
        :rtype: float
        """
        return self._lower_quartile

    @lower_quartile.setter
    def lower_quartile(self, lower_quartile):
        """
        Sets the lower_quartile of this SummaryStatistics.
        The middle number between the smallest number and the median of the data set. It's also known as the 25th quartile.


        :param lower_quartile: The lower_quartile of this SummaryStatistics.
        :type: float
        """
        self._lower_quartile = lower_quartile

    @property
    def upper_quartile(self):
        """
        **[Required]** Gets the upper_quartile of this SummaryStatistics.
        The middle number between the median and the largest number of the data set. It's also known as the 75th quartile.


        :return: The upper_quartile of this SummaryStatistics.
        :rtype: float
        """
        return self._upper_quartile

    @upper_quartile.setter
    def upper_quartile(self, upper_quartile):
        """
        Sets the upper_quartile of this SummaryStatistics.
        The middle number between the median and the largest number of the data set. It's also known as the 75th quartile.


        :param upper_quartile: The upper_quartile of this SummaryStatistics.
        :type: float
        """
        self._upper_quartile = upper_quartile

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateMaintenanceDetails(object):
    """
    The Maintenance Policy for the DB System.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateMaintenanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param window_start_time:
            The value to assign to the window_start_time property of this UpdateMaintenanceDetails.
        :type window_start_time: str

        """
        self.swagger_types = {
            'window_start_time': 'str'
        }

        self.attribute_map = {
            'window_start_time': 'windowStartTime'
        }

        self._window_start_time = None

    @property
    def window_start_time(self):
        """
        Gets the window_start_time of this UpdateMaintenanceDetails.
        The start of the 2 hour maintenance window.

        This string is of the format: \"{day-of-week} {time-of-day}\".

        \"{day-of-week}\" is a case-insensitive string like \"mon\", \"tue\", &c.

        \"{time-of-day}\" is the \"Time\" portion of an RFC3339-formatted timestamp. Any second or sub-second time data will be truncated to zero.


        :return: The window_start_time of this UpdateMaintenanceDetails.
        :rtype: str
        """
        return self._window_start_time

    @window_start_time.setter
    def window_start_time(self, window_start_time):
        """
        Sets the window_start_time of this UpdateMaintenanceDetails.
        The start of the 2 hour maintenance window.

        This string is of the format: \"{day-of-week} {time-of-day}\".

        \"{day-of-week}\" is a case-insensitive string like \"mon\", \"tue\", &c.

        \"{time-of-day}\" is the \"Time\" portion of an RFC3339-formatted timestamp. Any second or sub-second time data will be truncated to zero.


        :param window_start_time: The window_start_time of this UpdateMaintenanceDetails.
        :type: str
        """
        self._window_start_time = window_start_time

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateGoldenGateDetails(object):
    """
    Note: Deprecated. Use the new resource model APIs instead.
    Details about Oracle GoldenGate Microservices. If an empty object is specified, the stored Golden Gate details will be removed.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateGoldenGateDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param hub:
            The value to assign to the hub property of this UpdateGoldenGateDetails.
        :type hub: oci.database_migration.models.UpdateGoldenGateHub

        :param settings:
            The value to assign to the settings property of this UpdateGoldenGateDetails.
        :type settings: oci.database_migration.models.UpdateGoldenGateSettings

        """
        self.swagger_types = {
            'hub': 'UpdateGoldenGateHub',
            'settings': 'UpdateGoldenGateSettings'
        }

        self.attribute_map = {
            'hub': 'hub',
            'settings': 'settings'
        }

        self._hub = None
        self._settings = None

    @property
    def hub(self):
        """
        Gets the hub of this UpdateGoldenGateDetails.

        :return: The hub of this UpdateGoldenGateDetails.
        :rtype: oci.database_migration.models.UpdateGoldenGateHub
        """
        return self._hub

    @hub.setter
    def hub(self, hub):
        """
        Sets the hub of this UpdateGoldenGateDetails.

        :param hub: The hub of this UpdateGoldenGateDetails.
        :type: oci.database_migration.models.UpdateGoldenGateHub
        """
        self._hub = hub

    @property
    def settings(self):
        """
        Gets the settings of this UpdateGoldenGateDetails.

        :return: The settings of this UpdateGoldenGateDetails.
        :rtype: oci.database_migration.models.UpdateGoldenGateSettings
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """
        Sets the settings of this UpdateGoldenGateDetails.

        :param settings: The settings of this UpdateGoldenGateDetails.
        :type: oci.database_migration.models.UpdateGoldenGateSettings
        """
        self._settings = settings

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .change_email_domain_compartment_details import ChangeEmailDomainCompartmentDetails
from .change_sender_compartment_details import ChangeSenderCompartmentDetails
from .create_dkim_details import CreateDkimDetails
from .create_email_domain_details import CreateEmailDomainDetails
from .create_sender_details import CreateSenderDetails
from .create_suppression_details import CreateSuppressionDetails
from .dkim import Dkim
from .dkim_collection import DkimCollection
from .dkim_summary import DkimSummary
from .email_domain import EmailDomain
from .email_domain_collection import EmailDomainCollection
from .email_domain_summary import EmailDomainSummary
from .sender import Sender
from .sender_summary import SenderSummary
from .suppression import Suppression
from .suppression_summary import SuppressionSummary
from .update_dkim_details import UpdateDkimDetails
from .update_email_domain_details import UpdateEmailDomainDetails
from .update_sender_details import UpdateSenderDetails
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection

# Maps type names to classes for email services.
email_type_mapping = {
    "ChangeEmailDomainCompartmentDetails": ChangeEmailDomainCompartmentDetails,
    "ChangeSenderCompartmentDetails": ChangeSenderCompartmentDetails,
    "CreateDkimDetails": CreateDkimDetails,
    "CreateEmailDomainDetails": CreateEmailDomainDetails,
    "CreateSenderDetails": CreateSenderDetails,
    "CreateSuppressionDetails": CreateSuppressionDetails,
    "Dkim": Dkim,
    "DkimCollection": DkimCollection,
    "DkimSummary": DkimSummary,
    "EmailDomain": EmailDomain,
    "EmailDomainCollection": EmailDomainCollection,
    "EmailDomainSummary": EmailDomainSummary,
    "Sender": Sender,
    "SenderSummary": SenderSummary,
    "Suppression": Suppression,
    "SuppressionSummary": SuppressionSummary,
    "UpdateDkimDetails": UpdateDkimDetails,
    "UpdateEmailDomainDetails": UpdateEmailDomainDetails,
    "UpdateSenderDetails": UpdateSenderDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateNetworkLoadBalancerDetails(object):
    """
    Configuration details to update a network load balancer.

    **Caution:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateNetworkLoadBalancerDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateNetworkLoadBalancerDetails.
        :type display_name: str

        :param is_preserve_source_destination:
            The value to assign to the is_preserve_source_destination property of this UpdateNetworkLoadBalancerDetails.
        :type is_preserve_source_destination: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateNetworkLoadBalancerDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateNetworkLoadBalancerDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'is_preserve_source_destination': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'is_preserve_source_destination': 'isPreserveSourceDestination',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._is_preserve_source_destination = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateNetworkLoadBalancerDetails.
        The user-friendly display name for the network load balancer, which does not have to be unique and can be changed.
        Avoid entering confidential information.

        Example: `example_network_load_balancer`


        :return: The display_name of this UpdateNetworkLoadBalancerDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateNetworkLoadBalancerDetails.
        The user-friendly display name for the network load balancer, which does not have to be unique and can be changed.
        Avoid entering confidential information.

        Example: `example_network_load_balancer`


        :param display_name: The display_name of this UpdateNetworkLoadBalancerDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def is_preserve_source_destination(self):
        """
        Gets the is_preserve_source_destination of this UpdateNetworkLoadBalancerDetails.
        This parameter can be enabled only if backends are compute OCIDs. When enabled, the skipSourceDestinationCheck parameter is automatically
        enabled on the load balancer VNIC, and packets are sent to the backend with the entire IP header intact.


        :return: The is_preserve_source_destination of this UpdateNetworkLoadBalancerDetails.
        :rtype: bool
        """
        return self._is_preserve_source_destination

    @is_preserve_source_destination.setter
    def is_preserve_source_destination(self, is_preserve_source_destination):
        """
        Sets the is_preserve_source_destination of this UpdateNetworkLoadBalancerDetails.
        This parameter can be enabled only if backends are compute OCIDs. When enabled, the skipSourceDestinationCheck parameter is automatically
        enabled on the load balancer VNIC, and packets are sent to the backend with the entire IP header intact.


        :param is_preserve_source_destination: The is_preserve_source_destination of this UpdateNetworkLoadBalancerDetails.
        :type: bool
        """
        self._is_preserve_source_destination = is_preserve_source_destination

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateNetworkLoadBalancerDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateNetworkLoadBalancerDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateNetworkLoadBalancerDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateNetworkLoadBalancerDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateNetworkLoadBalancerDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateNetworkLoadBalancerDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateNetworkLoadBalancerDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateNetworkLoadBalancerDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RouteTable(object):
    """
    A collection of `RouteRule` objects, which are used to route packets
    based on destination IP to a particular network entity. For more information, see
    `Overview of the Networking Service`__.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
    talk to an administrator. If you're an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/overview.htm
    __ https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the lifecycle_state property of a RouteTable.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a RouteTable.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a RouteTable.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a RouteTable.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    def __init__(self, **kwargs):
        """
        Initializes a new RouteTable object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this RouteTable.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this RouteTable.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this RouteTable.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this RouteTable.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this RouteTable.
        :type id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this RouteTable.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param route_rules:
            The value to assign to the route_rules property of this RouteTable.
        :type route_rules: list[oci.core.models.RouteRule]

        :param time_created:
            The value to assign to the time_created property of this RouteTable.
        :type time_created: datetime

        :param vcn_id:
            The value to assign to the vcn_id property of this RouteTable.
        :type vcn_id: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'lifecycle_state': 'str',
            'route_rules': 'list[RouteRule]',
            'time_created': 'datetime',
            'vcn_id': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'lifecycle_state': 'lifecycleState',
            'route_rules': 'routeRules',
            'time_created': 'timeCreated',
            'vcn_id': 'vcnId'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._id = None
        self._lifecycle_state = None
        self._route_rules = None
        self._time_created = None
        self._vcn_id = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this RouteTable.
        The OCID of the compartment containing the route table.


        :return: The compartment_id of this RouteTable.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this RouteTable.
        The OCID of the compartment containing the route table.


        :param compartment_id: The compartment_id of this RouteTable.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this RouteTable.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this RouteTable.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this RouteTable.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this RouteTable.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this RouteTable.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this RouteTable.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this RouteTable.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this RouteTable.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this RouteTable.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this RouteTable.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this RouteTable.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this RouteTable.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this RouteTable.
        The route table's Oracle ID (OCID).


        :return: The id of this RouteTable.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RouteTable.
        The route table's Oracle ID (OCID).


        :param id: The id of this RouteTable.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this RouteTable.
        The route table's current state.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this RouteTable.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this RouteTable.
        The route table's current state.


        :param lifecycle_state: The lifecycle_state of this RouteTable.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def route_rules(self):
        """
        **[Required]** Gets the route_rules of this RouteTable.
        The collection of rules for routing destination IPs to network devices.


        :return: The route_rules of this RouteTable.
        :rtype: list[oci.core.models.RouteRule]
        """
        return self._route_rules

    @route_rules.setter
    def route_rules(self, route_rules):
        """
        Sets the route_rules of this RouteTable.
        The collection of rules for routing destination IPs to network devices.


        :param route_rules: The route_rules of this RouteTable.
        :type: list[oci.core.models.RouteRule]
        """
        self._route_rules = route_rules

    @property
    def time_created(self):
        """
        Gets the time_created of this RouteTable.
        The date and time the route table was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this RouteTable.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this RouteTable.
        The date and time the route table was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this RouteTable.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def vcn_id(self):
        """
        **[Required]** Gets the vcn_id of this RouteTable.
        The `OCID`__ of the VCN the route table list belongs to.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The vcn_id of this RouteTable.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this RouteTable.
        The `OCID`__ of the VCN the route table list belongs to.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param vcn_id: The vcn_id of this RouteTable.
        :type: str
        """
        self._vcn_id = vcn_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApiSpecificationRequestPolicies(object):
    """
    Global behavior applied to all requests received by the API.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApiSpecificationRequestPolicies object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param authentication:
            The value to assign to the authentication property of this ApiSpecificationRequestPolicies.
        :type authentication: oci.apigateway.models.AuthenticationPolicy

        :param rate_limiting:
            The value to assign to the rate_limiting property of this ApiSpecificationRequestPolicies.
        :type rate_limiting: oci.apigateway.models.RateLimitingPolicy

        :param cors:
            The value to assign to the cors property of this ApiSpecificationRequestPolicies.
        :type cors: oci.apigateway.models.CorsPolicy

        """
        self.swagger_types = {
            'authentication': 'AuthenticationPolicy',
            'rate_limiting': 'RateLimitingPolicy',
            'cors': 'CorsPolicy'
        }

        self.attribute_map = {
            'authentication': 'authentication',
            'rate_limiting': 'rateLimiting',
            'cors': 'cors'
        }

        self._authentication = None
        self._rate_limiting = None
        self._cors = None

    @property
    def authentication(self):
        """
        Gets the authentication of this ApiSpecificationRequestPolicies.

        :return: The authentication of this ApiSpecificationRequestPolicies.
        :rtype: oci.apigateway.models.AuthenticationPolicy
        """
        return self._authentication

    @authentication.setter
    def authentication(self, authentication):
        """
        Sets the authentication of this ApiSpecificationRequestPolicies.

        :param authentication: The authentication of this ApiSpecificationRequestPolicies.
        :type: oci.apigateway.models.AuthenticationPolicy
        """
        self._authentication = authentication

    @property
    def rate_limiting(self):
        """
        Gets the rate_limiting of this ApiSpecificationRequestPolicies.

        :return: The rate_limiting of this ApiSpecificationRequestPolicies.
        :rtype: oci.apigateway.models.RateLimitingPolicy
        """
        return self._rate_limiting

    @rate_limiting.setter
    def rate_limiting(self, rate_limiting):
        """
        Sets the rate_limiting of this ApiSpecificationRequestPolicies.

        :param rate_limiting: The rate_limiting of this ApiSpecificationRequestPolicies.
        :type: oci.apigateway.models.RateLimitingPolicy
        """
        self._rate_limiting = rate_limiting

    @property
    def cors(self):
        """
        Gets the cors of this ApiSpecificationRequestPolicies.

        :return: The cors of this ApiSpecificationRequestPolicies.
        :rtype: oci.apigateway.models.CorsPolicy
        """
        return self._cors

    @cors.setter
    def cors(self, cors):
        """
        Sets the cors of this ApiSpecificationRequestPolicies.

        :param cors: The cors of this ApiSpecificationRequestPolicies.
        :type: oci.apigateway.models.CorsPolicy
        """
        self._cors = cors

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
